/*
 * Log related functions/defines.
 *
 * Copyright (C) 2011-2013  Simon Ruderich
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "tlsproxy.h"
#include "log.h"

#include <pthread.h>
#include <stdarg.h>


void log_message(int level, const char *file, int line, const char *format, ...) {
    va_list ap;
    const char *level_string;

    if (global_log_level < level) {
        return;
    }

    switch (level) {
        case LOG_ERROR_LEVEL:   level_string = "ERROR "; break;
        case LOG_WARNING_LEVEL: level_string = " WARN "; break;
        case LOG_DEBUG1_LEVEL:  level_string = "DEBUG1"; break;
        case LOG_DEBUG2_LEVEL:  level_string = "DEBUG2"; break;
        default:                level_string = "UNKNOWN";
    }

#ifndef DEBUG
    /* Prevent warnings. */
    (void)file;
    (void)line;
#endif

    /* Prevent another thread from interrupting the printfs(). */
    flockfile(stderr);

#ifdef DEBUG
    fprintf(stderr, "%-12s:%-4d ", file, line);
#endif
    fprintf(stderr, "[%s] [%ld] ", level_string, (long)pthread_self());
    va_start(ap, format);
    vfprintf(stderr, format, ap);
    va_end(ap);
    fprintf(stderr, "\n");

    funlockfile(stderr);
}
